create function list_add(in_list text, in_add_value text)
  returns text
  comment '
 Description
 
 Takes a list, and a value to add to the list, and returns the resulting list.
 
 Useful for altering certain session variables, like sql_mode or optimizer_switch for instance.
 
 Parameters
 
 in_list (TEXT):
 The comma separated list to add a value to
 
 in_add_value (TEXT):
 The value to add to the input list
 
 Returns
 
 TEXT
 
 Example
 
 mysql> select @@sql_mode;
 +-----------------------------------------------------------------------------------+
 | @@sql_mode                                                                        |
 +-----------------------------------------------------------------------------------+
 | ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION |
 +-----------------------------------------------------------------------------------+
 1 row in set (0.00 sec)
 
 mysql> set sql_mode = sys.list_add(@@sql_mode, ''ANSI_QUOTES'');
 Query OK, 0 rows affected (0.06 sec)
 
 mysql> select @@sql_mode;
 +-----------------------------------------------------------------------------------------------+
 | @@sql_mode                                                                                    |
 +-----------------------------------------------------------------------------------------------+
 | ANSI_QUOTES,ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION |
 +-----------------------------------------------------------------------------------------------+
 1 row in set (0.00 sec)
 
 '
  BEGIN  IF (in_add_value IS NULL) THEN SIGNAL SQLSTATE '02200' SET MESSAGE_TEXT = 'Function sys.list_add: in_add_value input variable should not be NULL', MYSQL_ERRNO = 1138; END IF;  IF (in_list IS NULL OR LENGTH(in_list) = 0) THEN RETURN in_add_value; END IF;  RETURN (SELECT CONCAT(TRIM(BOTH ',' FROM TRIM(in_list)), ',', in_add_value));  END;

