create function list_drop(in_list text, in_drop_value text)
  returns text
  comment '
 Description
 
 Takes a list, and a value to attempt to remove from the list, and returns the resulting list.
 
 Useful for altering certain session variables, like sql_mode or optimizer_switch for instance.
 
 Parameters
 
 in_list (TEXT):
 The comma separated list to drop a value from
 
 in_drop_value (TEXT):
 The value to drop from the input list
 
 Returns
 
 TEXT
 
 Example
 
 mysql> select @@sql_mode;
 +-----------------------------------------------------------------------------------------------+
 | @@sql_mode                                                                                    |
 +-----------------------------------------------------------------------------------------------+
 | ANSI_QUOTES,ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION |
 +-----------------------------------------------------------------------------------------------+
 1 row in set (0.00 sec)
 
 mysql> set sql_mode = sys.list_drop(@@sql_mode, ''ONLY_FULL_GROUP_BY'');
 Query OK, 0 rows affected (0.03 sec)
 
 mysql> select @@sql_mode;
 +----------------------------------------------------------------------------+
 | @@sql_mode                                                                 |
 +----------------------------------------------------------------------------+
 | ANSI_QUOTES,STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION |
 +----------------------------------------------------------------------------+
 1 row in set (0.00 sec)
 
 '
  BEGIN  IF (in_drop_value IS NULL) THEN SIGNAL SQLSTATE '02200' SET MESSAGE_TEXT = 'Function sys.list_drop: in_drop_value input variable should not be NULL', MYSQL_ERRNO = 1138; END IF;  IF (in_list IS NULL OR LENGTH(in_list) = 0) THEN RETURN in_list; END IF;  RETURN (SELECT TRIM(BOTH ',' FROM REPLACE(REPLACE(CONCAT(',', in_list), CONCAT(',', in_drop_value), ''), CONCAT(', ', in_drop_value), '')));  END;

