create procedure ps_setup_disable_consumer(IN consumer varchar(128))
  comment '
 Description
 
 Disables consumers within Performance Schema 
 matching the input pattern.
 
 Parameters
 
 consumer (VARCHAR(128)):
 A LIKE pattern match (using "%consumer%") of consumers to disable
 
 Example
 
 To disable all consumers:
 
 mysql> CALL sys.ps_setup_disable_consumer('''');
 +--------------------------+
 | summary                  |
 +--------------------------+
 | Disabled 15 consumers    |
 +--------------------------+
 1 row in set (0.02 sec)
 
 To disable just the event_stage consumers:
 
 mysql> CALL sys.ps_setup_disable_comsumers(''stage'');
 +------------------------+
 | summary                |
 +------------------------+
 | Disabled 3 consumers   |
 +------------------------+
 1 row in set (0.00 sec)
 '
  BEGIN UPDATE performance_schema.setup_consumers SET enabled = 'NO' WHERE name LIKE CONCAT('%', consumer, '%');  SELECT CONCAT('Disabled ', @rows := ROW_COUNT(), ' consumer', IF(@rows != 1, 's', '')) AS summary; END;

