create procedure ps_setup_disable_thread(IN in_connection_id bigint)
  comment '
 Description
 
 Disable the given connection/thread in Performance Schema.
 
 Parameters
 
 in_connection_id (BIGINT):
 The connection ID (PROCESSLIST_ID from performance_schema.threads
 or the ID shown within SHOW PROCESSLIST)
 
 Example
 
 mysql> CALL sys.ps_setup_disable_thread(3);
 +-------------------+
 | summary           |
 +-------------------+
 | Disabled 1 thread |
 +-------------------+
 1 row in set (0.01 sec)
 
 To disable the current connection:
 
 mysql> CALL sys.ps_setup_disable_thread(CONNECTION_ID());
 +-------------------+
 | summary           |
 +-------------------+
 | Disabled 1 thread |
 +-------------------+
 1 row in set (0.00 sec)
 '
  BEGIN UPDATE performance_schema.threads SET instrumented = 'NO' WHERE processlist_id = in_connection_id;  SELECT CONCAT('Disabled ', @rows := ROW_COUNT(), ' thread', IF(@rows != 1, 's', '')) AS summary; END;

