create function ps_thread_id(in_connection_id bigint unsigned)
  returns bigint unsigned
  comment '
 Description
 
 Return the Performance Schema THREAD_ID for the specified connection ID.
 
 Parameters
 
 in_connection_id (BIGINT UNSIGNED):
 The id of the connection to return the thread id for. If NULL, the current
 connection thread id is returned.
 
 Example
 
 mysql> SELECT sys.ps_thread_id(79);
 +----------------------+
 | sys.ps_thread_id(79) |
 +----------------------+
 |                   98 |
 +----------------------+
 1 row in set (0.00 sec)
 
 mysql> SELECT sys.ps_thread_id(CONNECTION_ID());
 +-----------------------------------+
 | sys.ps_thread_id(CONNECTION_ID()) |
 +-----------------------------------+
 |                                98 |
 +-----------------------------------+
 1 row in set (0.00 sec)
 '
  BEGIN RETURN (SELECT THREAD_ID FROM `performance_schema`.`threads` WHERE PROCESSLIST_ID = IFNULL(in_connection_id, CONNECTION_ID()) ); END;

