create view user_summary as
  select if(isnull(`performance_schema`.`accounts`.`USER`), 'background',
            `performance_schema`.`accounts`.`USER`)                                                     AS `user`,
         sum(`stmt`.`total`)                                                                            AS `statements`,
         `sys`.`format_time`(sum(`stmt`.`total_latency`))                                               AS `statement_latency`,
         `sys`.`format_time`(
           ifnull((sum(`stmt`.`total_latency`) / nullif(sum(`stmt`.`total`), 0)), 0))                   AS `statement_avg_latency`,
         sum(`stmt`.`full_scans`)                                                                       AS `table_scans`,
         sum(`io`.`ios`)                                                                                AS `file_ios`,
         `sys`.`format_time`(sum(`io`.`io_latency`))                                                    AS `file_io_latency`,
         sum(`performance_schema`.`accounts`.`CURRENT_CONNECTIONS`)                                     AS `current_connections`,
         sum(`performance_schema`.`accounts`.`TOTAL_CONNECTIONS`)                                       AS `total_connections`,
         count(distinct `performance_schema`.`accounts`.`HOST`)                                         AS `unique_hosts`,
         `sys`.`format_bytes`(sum(`mem`.`current_allocated`))                                           AS `current_memory`,
         `sys`.`format_bytes`(sum(`mem`.`total_allocated`))                                             AS `total_memory_allocated`
  from (((`performance_schema`.`accounts` left join `sys`.`x$user_summary_by_statement_latency` `stmt` on ((
    if(isnull(`performance_schema`.`accounts`.`USER`), 'background', `performance_schema`.`accounts`.`USER`) =
    `stmt`.`user`))) left join `sys`.`x$user_summary_by_file_io` `io` on ((
    if(isnull(`performance_schema`.`accounts`.`USER`), 'background', `performance_schema`.`accounts`.`USER`) =
    `io`.`user`))) left join `sys`.`x$memory_by_user_by_current_bytes` `mem` on ((
    if(isnull(`performance_schema`.`accounts`.`USER`), 'background', `performance_schema`.`accounts`.`USER`) =
    `mem`.`user`)))
  group by if(isnull(`performance_schema`.`accounts`.`USER`), 'background', `performance_schema`.`accounts`.`USER`)
  order by sum(`stmt`.`total_latency`) desc;

